@@ -567,7 +567,6 @@ class VariableOsDiskContent(ReadonlyVariable):
         return map(lambda x: "",
                    self.Get('os_disk_dev'))
 
-
 class VariableOsDiskFormat(ReadonlyVariable):
     """
     Filesystem on device partitions
@@ -584,6 +583,9 @@ class VariableOsDiskFormat(ReadonlyVariable):
                  fstab.getBy(what=fstab.TYPE, eq=dev) or \
                  prop.get('ID_FS_TYPE', '')
             if fs == "btrfs":
+                if "compress" in fstab.getBy(what=fstab.OPTS,
+                    eq=dev):
+                    return "btrfs-compress"
                 try:
                     if Btrfs(dev).compression != "":   
                         return "btrfs-compress"
@@ -1349,6 +1351,8 @@ class VariableOsLocationFormat(LocationHelper, Variable):
                     'os_format_use', os_format_type=_format, limit=1) == "yes":
                     default_format = _format
                     break
+        else:
+            root_format = None
 
         def wrap(info):
             dev, mount, fs = info
@@ -1357,6 +1361,8 @@ class VariableOsLocationFormat(LocationHelper, Variable):
                     return "swap"
                 elif mount.startswith('/boot/efi'):
                     return "vfat"
+                if mount == "/" and root_format and root_format in allAvailFS:
+                    return root_format
                 if dev in diskFormat and diskFormat[dev] in allAvailFS:
                     if mount.count('/') == 1 or mount == "/var/calculate":
                         if FileSystemManager.checkFSForTypeMount(
